==> rxq-add-ons-0.0.4.tgz: package/_esm5/src/createDynamicObject.js <==
var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

import { createSessionObject } from "rxq/operators/doc";
import { setProperties } from "rxq/operators/genericobject";
import { first, combineLatest, mergeMap, skip, publish } from "rxjs/operators";
import { of } from "rxjs/observable/of";

export default function createDynamicObject(def$) {
    return function (app$) {

        var firstDef$ = def$.pipe(first());
        var newDef$ = def$.pipe(skip(1));

        // Create object if not already created
        var obj$ = app$.pipe(combineLatest(firstDef$), mergeMap(function (_ref) {
            var _ref2 = _slicedToArray(_ref, 2),
                appHandle = _ref2[0],
                def = _ref2[1];

            return of(appHandle).pipe(createSessionObject(def));
        }));

        // Update object; Always connected, may need better way to handle connecting & disconnecting this
        obj$.pipe(combineLatest(newDef$), mergeMap(function (_ref3) {
            var _ref4 = _slicedToArray(_ref3, 2),
                objHandle = _ref4[0],
                def = _ref4[1];

            return of(objHandle).pipe(setProperties(def));
        }), publish()).connect();

        return obj$;
    };
}

==> rxq-add-ons-0.0.7.tgz: package/_esm5/src/createDynamicObject.js <==
var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

import { createSessionObject } from "rxq/operators/doc";
import { setProperties } from "rxq/operators/genericobject";
import { first, combineLatest, mergeMap, skip, publish, mapTo, switchMap } from "rxjs/operators";
import { of } from "rxjs/observable/of";

export default function createDynamicObject(def$) {
    var firstDef$ = def$.pipe(first());
    var newDef$ = def$.pipe(skip(1));

    return function (app$) {

        // Create object if not already created
        var obj$ = app$.pipe(combineLatest(firstDef$), mergeMap(function (_ref) {
            var _ref2 = _slicedToArray(_ref, 2),
                appHandle = _ref2[0],
                def = _ref2[1];

            return of(appHandle).pipe(createSessionObject(def));
        }));

        // Update object; Always connected, may need better way to handle connecting & disconnecting this
        obj$.pipe(combineLatest(newDef$), switchMap(function (_ref3) {
            var _ref4 = _slicedToArray(_ref3, 2),
                objHandle = _ref4[0],
                def = _ref4[1];

            var h$ = of(objHandle);
            return h$.pipe(setProperties(def), mapTo(objHandle));
        }), publish()).connect();

        return obj$;
    };
}
